@@ -2,14 +2,16 @@
 
 from ._debiased_bce import XGBSEDebiasedBCE
 from ._kaplan_neighbors import XGBSEKaplanNeighbors, XGBSEKaplanTree
+from ._stacked_weibull import XGBSEStackedWeibull
 from ._meta import XGBSEBootstrapEstimator
 
 
-__version__ = "0.1.1"
+__version__ = "0.2.1"
 
 __all__ = [
     "XGBSEDebiasedBCE",
     "XGBSEKaplanNeighbors",
     "XGBSEKaplanTree",
+    "XGBSEStackedWeibull",
     "XGBSEBootstrapEstimator",
 ]
